@@ -19,7 +19,12 @@ version = ".".join(str(x) for x in ver_dic["VERSION"])
 release = ver_dic["VERSION_TEXT"]
 
 intersphinx_mapping = {
-    "https://docs.python.org/3": None,
-    "https://numpy.org/doc/stable/": None,
-    "https://documen.tician.de/codepy/": None,
+    "python": ("https://docs.python.org/3", None),
+    "numpy": ("https://numpy.org/doc/stable/", None),
+    "codepy": ("https://documen.tician.de/codepy/", None),
+    "pytest": ("https://docs.pytest.org/en/stable/", None),
 }
+
+nitpick_ignore_regex = [
+    ["py:class", r"numpy.(float32|u?int32)"],  # not sure why these don't work?
+]
