@@ -6,15 +6,16 @@ import numpy
 free_bytes, total_bytes = cuda.mem_get_info()
 exp = 10
 while True:
-    fill_floats = free_bytes / 4 - (1<<exp)
+    fill_floats = free_bytes // 4 - (1 << exp)
     if fill_floats < 0:
         raise RuntimeError("couldn't find allocatable size")
+    print("alloc", fill_floats)
     try:
-        print("alloc", fill_floats)
         ary = gpuarray.empty((fill_floats,), dtype=numpy.float32)
-        break
-    except:
+    except cuda.MemoryError:
         pass
+    else:
+        break
 
     exp += 1
 
