@@ -159,6 +159,26 @@ class TestGPUArray:
         b_mul_c = (b_gpu * c_gpu).get()
         assert (b * c == b_mul_c).all()
 
+    def test_mul_add(self):
+        """Test the addition-multiplication of two arrays."""
+
+        a = np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10]).astype(np.float32)
+        b = np.array([10, 20, 30, 40, 50, 60, 70, 80, 90, 100]).astype(np.float32)
+
+        a_gpu = gpuarray.to_gpu(a)
+        b_gpu = gpuarray.to_gpu(b)
+        c_gpu = gpuarray.empty_like(a_gpu)
+
+        res = a_gpu.mul_add(2, b_gpu, 3).get()
+        assert (2 * a + 3 * b == res).all()
+
+        a_gpu.mul_add(2, b_gpu, 3, out=c_gpu)
+        assert (2 * a + 3 * b == c_gpu.get()).all()
+
+        stream = drv.Stream()
+        res = a_gpu.mul_add(2, b_gpu, 3, stream=stream).get()
+        assert (2 * a + 3 * b == res).all()
+
     def test_unit_multiply_array(self):
 
         a = np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10]).astype(np.float32)
@@ -676,6 +696,9 @@ class TestGPUArray:
             assert la.norm(a_cpu - a_gpu.get()) == 0, i
 
     def test_take(self):
+        if drv.get_driver_version() // 1000 >= 12:
+            pytest.skip("texture references were removed in CUDA 12")
+
         idx = gpuarray.arange(0, 10000, 2, dtype=np.uint32)
         for dtype in [np.float32, np.complex64]:
             a = gpuarray.arange(0, 600000, dtype=np.uint32).astype(dtype)
@@ -862,6 +885,50 @@ class TestGPUArray:
 
             assert min_a_gpu == min_a
 
+    def test_subset_sum(self):
+        """Test subset sum with annd without allocator"""
+
+        l_a = 2000
+        gran = 5
+        l_m = l_a - l_a // gran + 1
+
+        if has_double_support():
+            dtypes = [np.float64, np.float32, np.int32]
+        else:
+            dtypes = [np.float32, np.int32]
+
+        import pycuda.tools
+        for pool in [None, pycuda.tools.DeviceMemoryPool()]:
+            for dtype in dtypes:
+                a = np.random.uniform(0, 10, l_a).astype(dtype)
+                a_gpu = gpuarray.to_gpu(a)
+
+                meaningful_indices_gpu = gpuarray.zeros(l_m, dtype=np.int32)
+                meaningful_indices = meaningful_indices_gpu.get()
+                j = 0
+                for i in range(len(meaningful_indices)):
+                    meaningful_indices[i] = j
+                    j = j + 1
+                    if j % gran == 0:
+                        j = j + 1
+
+                meaningful_indices_gpu = gpuarray.to_gpu(meaningful_indices)
+
+                sum_a = a[meaningful_indices].sum()
+
+                alloc_uses = 0
+
+                def allocator(size):
+                    nonlocal alloc_uses, pool
+                    alloc_uses += 1
+                    return pool.allocate(size)
+
+                alloc = None if pool is None else allocator
+                sum_a_gpu = gpuarray.subset_sum(meaningful_indices_gpu, a_gpu, allocator=alloc).get()
+                assert np.allclose(sum_a_gpu, sum_a)
+                if pool is not None:
+                    assert alloc_uses == 1
+
     @pytest.mark.parametrize("sz", [2,
                                     3,
                                     4,
@@ -991,6 +1058,9 @@ class TestGPUArray:
         assert la.norm(min_a_b_gpu.get() - np.minimum(a, b)) == 0
 
     def test_take_put(self):
+        if drv.get_driver_version() // 1000 >= 12:
+            pytest.skip("texture references were removed in CUDA 12")
+
         for n in [5, 17, 333]:
             one_field_size = 8
             buf_gpu = gpuarray.zeros(n * one_field_size, dtype=np.float32)
@@ -1312,7 +1382,7 @@ class TestGPUArray:
         for i in range(10):
             red(a_gpu[i], out=max_gpu[i])
 
-        assert np.alltrue(a.max(axis=1) == max_gpu.get())
+        assert np.all(a.max(axis=1) == max_gpu.get())
 
     def test_sum_allocator(self):
         # FIXME
